Discover Packages
github.com/Nbyete/common/fioss
config
package
Version:
v0.0.0-...-b08fcc5
Opens a new window with list of versions in this module.
Published: Jun 22, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
var ImageExt = []string {"bmp", "jpeg", "jpg", "gif", "psd", "png", "tiff", "tga", "eps"}
图片后缀
type AWSConf struct {
Addr string `json:"addr"`
Bucket string `json:"bucket"`
AccessID string `json:"access_id"`
AccessSecret string `json:"access_secret"`
CDN string `json:"cdn"`
REGION string `json:"region"`
}
type COSConf struct {
Addr string `json:"addr"`
SecretID string `json:"secret_id"`
SecretKey string `json:"secret_key"`
CDN string `json:"cdn"`
Perfix string `json:"perfix"`
}
type OSSConf struct {
Addr string `json:"addr"`
Endpoint string `json:"endpoint"`
Bucket string `json:"bucket"`
AccessID string `json:"access_id"`
AccessSecret string `json:"access_secret"`
CDN string `json:"cdn"`
Perfix string `json:"perfix"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.